@@ -1,10 +1,10 @@
 from importlib.metadata import PackageNotFoundError, version
 
-from movement.logging import configure_logging
+from movement.utils.logging import logger
 
 try:
     __version__ = version("movement")
-except PackageNotFoundError:
+except PackageNotFoundError:  # pragma: no cover
     # package is not installed
     pass
 
@@ -13,5 +13,5 @@ import xarray as xr
 
 xr.set_options(keep_attrs=True, display_expand_data=False)
 
-# initialize logger upon import
-configure_logging()
+# Configure logging to stderr and a file
+logger.configure()
